@@ -37,8 +37,6 @@ use warnings;
 
 use Try::Tiny;
 
-use Module::Load ();
-
 use Crypt::Perl::BigInt ();
 use Crypt::Perl::X ();
 
@@ -53,8 +51,11 @@ use Crypt::Perl::X ();
 #   y^2 = x^3 + ax + b
 #----------------------------------------------------------------------
 
-use constant CURVE_ORDER => qw( p a b n h gx gy );
-use constant GETTER_CURVE_ORDER => ( CURVE_ORDER(), 'seed' );
+#“h” is determinable from the other curve parameters
+#and should not be considered necessary to match.
+use constant CURVE_EQUIVALENCY => qw( p a b n gx gy );
+
+use constant GETTER_CURVE_ORDER => ( CURVE_EQUIVALENCY(), 'h', 'seed' );
 
 sub get_oid_for_curve_name {
     my ($name) = @_;
@@ -62,7 +63,7 @@ sub get_oid_for_curve_name {
     my $name_alt = $name;
     $name_alt =~ tr<-><_>;
 
-    Module::Load::load('Crypt::Perl::ECDSA::EC::CurvesDB');
+    require Crypt::Perl::ECDSA::EC::CurvesDB;
 
     my $translator_cr = Crypt::Perl::ECDSA::EC::CurvesDB->can("OID_$name_alt");
     die Crypt::Perl::X::create('ECDSA::NoCurveForName', $name) if !$translator_cr;
@@ -75,7 +76,7 @@ sub get_curve_name_by_data {
 
     my %hex_data = map { $_ => substr( $data_hr->{$_}->as_hex(), 2 ) } keys %$data_hr;
 
-    Module::Load::load('Crypt::Perl::ECDSA::EC::CurvesDB');
+    require Crypt::Perl::ECDSA::EC::CurvesDB;
 
     my $ns = \%Crypt::Perl::ECDSA::EC::CurvesDB::;
 
@@ -108,18 +109,28 @@ sub get_curve_name_by_data {
 
         next if !$db_hex_data_hr;  #i.e., if we have no params for the OID
 
-        for my $k ( CURVE_ORDER() ) {
-#print "$key-$k ($hex_data{$k}) ($db_hex_data_hr->{$k})\n";
+        for my $k ( CURVE_EQUIVALENCY() ) {
             next NS_KEY if $hex_data{$k} ne $db_hex_data_hr->{$k};
         }
 
         #We got a match!
+
         my $name = substr($key, 4);  # strip leading “OID_”
 
         #We store dashes as underscores so we can use the namespace.
         #Hopefully no curve OID name will ever contain an underscore!!
         $name =~ tr<_><->;
 
+        #… but let’s make sure the extras (cofactor and seed) are correct,
+        #if given. Note that all curves have cofactor == 1 except secp112r2 and
+        #secp128r2, both of which have cofactor == 4.
+        #
+        for my $k ( qw( h seed ) ) {
+            if ( defined $hex_data{$k} && $hex_data{$k} ne $db_hex_data_hr->{$k} ) {
+                die Crypt::Perl::X::create('Generic', "Curve parameters match “$name”, but “$k” ($hex_data{$k}) does not match expected value ($db_hex_data_hr->{$k})!");
+            }
+        }
+
         return $name;
     }
 
@@ -152,7 +163,7 @@ sub _get_curve_hex_data_by_oid {
     my $const = "CURVE_$oid";
     $const =~ tr<.><_>;
 
-    Module::Load::load('Crypt::Perl::ECDSA::EC::CurvesDB');
+    require Crypt::Perl::ECDSA::EC::CurvesDB;
 
     my $getter_cr = Crypt::Perl::ECDSA::EC::CurvesDB->can($const);
     die Crypt::Perl::X::create('ECDSA::NoCurveForOID', $oid) if !$getter_cr;
